==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressStatusFluent<A extends IngressStatusFluent<A>> extends Fluent<A>{
  public A addToComponentRoutes(Integer index,ComponentRouteStatus item);
  public A setToComponentRoutes(Integer index,ComponentRouteStatus item);
  public A addToComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... items);
  public A addAllToComponentRoutes(Collection<ComponentRouteStatus> items);
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... items);
  public A removeAllFromComponentRoutes(Collection<ComponentRouteStatus> items);
  public A removeMatchingFromComponentRoutes(Predicate<ComponentRouteStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ComponentRouteStatus> getComponentRoutes();
  public List<ComponentRouteStatus> buildComponentRoutes();
  public ComponentRouteStatus buildComponentRoute(Integer index);
  public ComponentRouteStatus buildFirstComponentRoute();
  public ComponentRouteStatus buildLastComponentRoute();
  public ComponentRouteStatus buildMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public Boolean hasMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public A withComponentRoutes(List<ComponentRouteStatus> componentRoutes);
  public A withComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... componentRoutes);
  public Boolean hasComponentRoutes();
  public IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRouteLike(ComponentRouteStatus item);
  public IngressStatusFluent.ComponentRoutesNested<A> setNewComponentRouteLike(Integer index,ComponentRouteStatus item);
  public IngressStatusFluent.ComponentRoutesNested<A> editComponentRoute(Integer index);
  public IngressStatusFluent.ComponentRoutesNested<A> editFirstComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> editLastComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> editMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ComponentRoutesNested<N> extends Nested<N>,ComponentRouteStatusFluent<IngressStatusFluent.ComponentRoutesNested<N>>{
    public N and();
    public N endComponentRoute();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressStatusFluent<A extends IngressStatusFluent<A>> extends Fluent<A>{
  public A addToComponentRoutes(int index,ComponentRouteStatus item);
  public A setToComponentRoutes(int index,ComponentRouteStatus item);
  public A addToComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... items);
  public A addAllToComponentRoutes(Collection<ComponentRouteStatus> items);
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... items);
  public A removeAllFromComponentRoutes(Collection<ComponentRouteStatus> items);
  public A removeMatchingFromComponentRoutes(Predicate<ComponentRouteStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ComponentRouteStatus> getComponentRoutes();
  public List<ComponentRouteStatus> buildComponentRoutes();
  public ComponentRouteStatus buildComponentRoute(int index);
  public ComponentRouteStatus buildFirstComponentRoute();
  public ComponentRouteStatus buildLastComponentRoute();
  public ComponentRouteStatus buildMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public Boolean hasMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public A withComponentRoutes(List<ComponentRouteStatus> componentRoutes);
  public A withComponentRoutes(io.fabric8.openshift.api.model.config.v1.ComponentRouteStatus... componentRoutes);
  public Boolean hasComponentRoutes();
  public IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRouteLike(ComponentRouteStatus item);
  public IngressStatusFluent.ComponentRoutesNested<A> setNewComponentRouteLike(int index,ComponentRouteStatus item);
  public IngressStatusFluent.ComponentRoutesNested<A> editComponentRoute(int index);
  public IngressStatusFluent.ComponentRoutesNested<A> editFirstComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> editLastComponentRoute();
  public IngressStatusFluent.ComponentRoutesNested<A> editMatchingComponentRoute(Predicate<ComponentRouteStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ComponentRoutesNested<N> extends Nested<N>,ComponentRouteStatusFluent<IngressStatusFluent.ComponentRoutesNested<N>>{
    public N and();
    public N endComponentRoute();
    
  }
  
}
